# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`firewalld`](#firewalld): Manage the firewalld service
* [`firewalld::reload`](#firewalld--reload): A common point for triggering an intermediary firewalld reload using firewall-cmd
* [`firewalld::reload::complete`](#firewalld--reload--complete): A common point for triggering an intermediary firewalld full reload using firewall-cmd

### Resource types

* [`firewalld_custom_service`](#firewalld_custom_service): Creates a custom firewalld service.
* [`firewalld_direct_chain`](#firewalld_direct_chain): Allow to create a custom chain in iptables/ip6tables/ebtables using firewalld direct interface.  Example:      firewalld_direct_chain {'Add c
* [`firewalld_direct_passthrough`](#firewalld_direct_passthrough): Allow to create a custom passthroughhrough traffic in iptables/ip6tables/ebtables using firewalld direct interface.  Example:      firewalld_
* [`firewalld_direct_purge`](#firewalld_direct_purge): Allow to purge direct rules in iptables/ip6tables/ebtables using firewalld direct interface.  Example:      firewalld_direct_purge {'chain': 
* [`firewalld_direct_rule`](#firewalld_direct_rule): Allow to pass rules directly to iptables/ip6tables/ebtables using firewalld direct interface.  Example:      firewalld_direct_rule {'Allow ou
* [`firewalld_ipset`](#firewalld_ipset): Configure IPsets in Firewalld  Example:     firewalld_ipset {'internal net':         ensure   => 'present',         type     => 'hash:net',  
* [`firewalld_policy`](#firewalld_policy): Creates and manages firewalld policies.
* [`firewalld_port`](#firewalld_port): Assigns a port to a specific firewalld zone.  firewalld_port will autorequire the firewalld_zone specified in the zone parameter or the firew
* [`firewalld_rich_rule`](#firewalld_rich_rule): Manages firewalld rich rules.  firewalld_rich_rules will autorequire the firewalld_zone specified in the zone parameter or the firewalld_poli
* [`firewalld_service`](#firewalld_service): Assigns a service to a specific firewalld zone.
* [`firewalld_zone`](#firewalld_zone): Creates and manages firewalld zones.

### Functions

* [`firewalld::safe_filename`](#firewalld--safe_filename): Returns a string that is safe for firewalld filenames

## Classes

### <a name="firewalld"></a>`firewalld`

See the README.md for usage instructions for the firewalld_zone and
firewalld_rich_rule types

=== Examples

 Standard:
   include firewalld

 Command line only, no GUI components:
   class{'firewalld':
   }

 With GUI components
   class{'firewalld':
     install_gui => true,
   }

=== Documentation

=== Authors

Craig Dunn <craig@craigdunn.org>

=== Copyright

Copyright 2015 Craig Dunn

#### Parameters

The following parameters are available in the `firewalld` class:

* [`package_ensure`](#-firewalld--package_ensure)
* [`package`](#-firewalld--package)
* [`service_enable`](#-firewalld--service_enable)
* [`service_ensure`](#-firewalld--service_ensure)
* [`install_gui`](#-firewalld--install_gui)
* [`config_package`](#-firewalld--config_package)
* [`zones`](#-firewalld--zones)
* [`policies`](#-firewalld--policies)
* [`ports`](#-firewalld--ports)
* [`services`](#-firewalld--services)
* [`rich_rules`](#-firewalld--rich_rules)
* [`custom_services`](#-firewalld--custom_services)
* [`ipsets`](#-firewalld--ipsets)
* [`direct_rules`](#-firewalld--direct_rules)
* [`direct_chains`](#-firewalld--direct_chains)
* [`direct_passthroughs`](#-firewalld--direct_passthroughs)
* [`purge_direct_rules`](#-firewalld--purge_direct_rules)
* [`purge_direct_chains`](#-firewalld--purge_direct_chains)
* [`purge_direct_passthroughs`](#-firewalld--purge_direct_passthroughs)
* [`purge_unknown_ipsets`](#-firewalld--purge_unknown_ipsets)
* [`default_zone`](#-firewalld--default_zone)
* [`log_denied`](#-firewalld--log_denied)
* [`cleanup_on_exit`](#-firewalld--cleanup_on_exit)
* [`zone_drifting`](#-firewalld--zone_drifting)
* [`minimal_mark`](#-firewalld--minimal_mark)
* [`lockdown`](#-firewalld--lockdown)
* [`individual_calls`](#-firewalld--individual_calls)
* [`ipv6_rpfilter`](#-firewalld--ipv6_rpfilter)
* [`firewall_backend`](#-firewalld--firewall_backend)
* [`default_service_zone`](#-firewalld--default_service_zone)
* [`default_port_zone`](#-firewalld--default_port_zone)
* [`default_port_protocol`](#-firewalld--default_port_protocol)

##### <a name="-firewalld--package_ensure"></a>`package_ensure`

Data type: `Enum['present','absent','latest','installed']`

Define if firewalld-package should be handled
Defaults to `installed` but can be set to `absent` or `latest`

Default value: `'installed'`

##### <a name="-firewalld--package"></a>`package`

Data type: `String`

The name of the `firewalld`-package

Default value: `'firewalld'`

##### <a name="-firewalld--service_enable"></a>`service_enable`

Data type: `Boolean`

If the `firewalld`-service should be enabled

Default value: `true`

##### <a name="-firewalld--service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

The state that the `firewalld`-service should be in

Default value: `'running'`

##### <a name="-firewalld--install_gui"></a>`install_gui`

Data type: `Boolean`

Set to true to install the `firewall-config`-package

Default value: `false`

##### <a name="-firewalld--config_package"></a>`config_package`

Data type: `String`

The name of package that is installed if `install_gui` is true

Default value: `'firewall-config'`

##### <a name="-firewalld--zones"></a>`zones`

Data type: `Hash`

A hash of `firewalld_zone`-definitions

Default value: `{}`

##### <a name="-firewalld--policies"></a>`policies`

Data type: `Hash`

A hash of `firewalld_policy`-definitions

Default value: `{}`

##### <a name="-firewalld--ports"></a>`ports`

Data type: `Hash`

A hash of `firewalld_port`-definitions

Default value: `{}`

##### <a name="-firewalld--services"></a>`services`

Data type: `Hash`

A hash of `firewalld_service`-definitions

Default value: `{}`

##### <a name="-firewalld--rich_rules"></a>`rich_rules`

Data type: `Hash`

A hash of `firewalld_rich_rule`-definitions

Default value: `{}`

##### <a name="-firewalld--custom_services"></a>`custom_services`

Data type: `Hash`

A hash of `firewalld_custom_service`-definitions

Default value: `{}`

##### <a name="-firewalld--ipsets"></a>`ipsets`

Data type: `Hash`

A hash of `firewalld_ipset`-definitions

Default value: `{}`

##### <a name="-firewalld--direct_rules"></a>`direct_rules`

Data type: `Hash`

A hash of `firewalld_direct_rule`-definitions

Default value: `{}`

##### <a name="-firewalld--direct_chains"></a>`direct_chains`

Data type: `Hash`

A hash of `firewalld_direct_chain`-definitions

Default value: `{}`

##### <a name="-firewalld--direct_passthroughs"></a>`direct_passthroughs`

Data type: `Hash`

A hash of `firewalld_direct_passthrough`-definitions

Default value: `{}`

##### <a name="-firewalld--purge_direct_rules"></a>`purge_direct_rules`

Data type: `Boolean`

If direct_rules not maintained by puppet should be removed

Default value: `false`

##### <a name="-firewalld--purge_direct_chains"></a>`purge_direct_chains`

Data type: `Boolean`

If direct_chains not maintained by puppet should be removed

Default value: `false`

##### <a name="-firewalld--purge_direct_passthroughs"></a>`purge_direct_passthroughs`

Data type: `Boolean`

If direct_passthroughs not maintained by puppet should be removed

Default value: `false`

##### <a name="-firewalld--purge_unknown_ipsets"></a>`purge_unknown_ipsets`

Data type: `Boolean`

If ipsets not maintained by puppet should be removed

Default value: `false`

##### <a name="-firewalld--default_zone"></a>`default_zone`

Data type: `Optional[String]`

Optional string to set the default zone

Default value: `undef`

##### <a name="-firewalld--log_denied"></a>`log_denied`

Data type: `Optional[Enum['off','all','unicast','broadcast','multicast']]`

Sets the mode for which denied packets should be logged

Default value: `undef`

##### <a name="-firewalld--cleanup_on_exit"></a>`cleanup_on_exit`

Data type: `Optional[Enum['yes', 'no']]`

Controls the `CleanupOnExit` setting of `firewalld`

Default value: `undef`

##### <a name="-firewalld--zone_drifting"></a>`zone_drifting`

Data type: `Optional[Enum['yes', 'no']]`

Controls the `AllowZoneDrifting` setting of `firewalld`
should be `no` because zone-drifting is deprecated

Default value: `undef`

##### <a name="-firewalld--minimal_mark"></a>`minimal_mark`

Data type: `Optional[Integer]`

Controls the `MinimalMark` setting of `firewalld`

Default value: `undef`

##### <a name="-firewalld--lockdown"></a>`lockdown`

Data type: `Optional[Enum['yes', 'no']]`

Controls the `Lockdown` setting of `firewalld`

Default value: `undef`

##### <a name="-firewalld--individual_calls"></a>`individual_calls`

Data type: `Optional[Enum['yes', 'no']]`

Controls the `IndividualCalls` setting of `firewalld`

Default value: `undef`

##### <a name="-firewalld--ipv6_rpfilter"></a>`ipv6_rpfilter`

Data type: `Optional[Enum['yes', 'no']]`

Controls the `IPv6_rpfilter` setting of `firewalld`

Default value: `undef`

##### <a name="-firewalld--firewall_backend"></a>`firewall_backend`

Data type: `Optional[Enum['iptables', 'nftables']]`

Chooses the backend between `iptables` (deprecated) or `nftables`

Default value: `undef`

##### <a name="-firewalld--default_service_zone"></a>`default_service_zone`

Data type: `Optional[String]`

Sets the default zone for `firewalld_service`

Default value: `undef`

##### <a name="-firewalld--default_port_zone"></a>`default_port_zone`

Data type: `Optional[String]`

Sets the default zone for `firewalld_port`

Default value: `undef`

##### <a name="-firewalld--default_port_protocol"></a>`default_port_protocol`

Data type: `Optional[String]`

Sets the default protocol for `firewalld_port`

Default value: `undef`

### <a name="firewalld--reload"></a>`firewalld::reload`

A common point for triggering an intermediary firewalld reload using firewall-cmd

### <a name="firewalld--reload--complete"></a>`firewalld::reload::complete`

A common point for triggering an intermediary firewalld full reload using firewall-cmd

## Resource types

### <a name="firewalld_custom_service"></a>`firewalld_custom_service`

You will still need to create a `firewalld_service` resource to bind your new
service to a zone.

#### Examples

##### Creating a custom 'test' service

```puppet
firewalld_custom_service {'test':
    ensure  => present,
    ports   => [{'port' => '1234', 'protocol' => 'tcp'}]
}
```

#### Properties

The following properties are available in the `firewalld_custom_service` type.

##### `description`

Valid values: `%r{.+}`

The long description of the service

##### `ensure`

Valid values: `present`, `absent`

Manage the state of this type.

Default value: `present`

##### `ipv4_destination`

The IPv4 destination network of the service

Default value: `unset`

##### `ipv6_destination`

The IPv6 destination network of the service

Default value: `unset`

##### `modules`

Valid values: `%r{^[\w-]+$}`

The list of netfilter modules to add to the service

Default value: `unset`

##### `ports`

An Array of allowed port/protocol Hashes or Strings of the form `port/protocol`

Default value: `unset`

##### `protocols`

Valid values: `%r{^[^\s#]+$}`

Protocols allowed by the service as defined in /etc/protocols

Default value: `unset`

##### `short`

Valid values: `%r{.+}`

The short description of the service

#### Parameters

The following parameters are available in the `firewalld_custom_service` type.

* [`name`](#-firewalld_custom_service--name)
* [`provider`](#-firewalld_custom_service--provider)

##### <a name="-firewalld_custom_service--name"></a>`name`

Valid values: `%r{.+}`

namevar

The target filename of the resource (without the .xml suffix)

##### <a name="-firewalld_custom_service--provider"></a>`provider`

The specific backend to use for this `firewalld_custom_service` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

### <a name="firewalld_direct_chain"></a>`firewalld_direct_chain`

Allow to create a custom chain in iptables/ip6tables/ebtables using firewalld direct interface.

Example:

    firewalld_direct_chain {'Add custom chain LOG_DROPS':
        name           => 'LOG_DROPS',
        ensure         => 'present',
        inet_protocol  => 'ipv4',
        table          => 'filter'
    }

#### Properties

The following properties are available in the `firewalld_direct_chain` type.

##### `ensure`

Valid values: `present`, `absent`

Manage the state of this type.

Default value: `present`

#### Parameters

The following parameters are available in the `firewalld_direct_chain` type.

* [`inet_protocol`](#-firewalld_direct_chain--inet_protocol)
* [`name`](#-firewalld_direct_chain--name)
* [`provider`](#-firewalld_direct_chain--provider)
* [`table`](#-firewalld_direct_chain--table)

##### <a name="-firewalld_direct_chain--inet_protocol"></a>`inet_protocol`

Valid values: `ipv4`, `ipv6`, `eb`

namevar

Name of the TCP/IP protocol to use (e.g: ipv4, ipv6, eb)

Default value: `ipv4`

##### <a name="-firewalld_direct_chain--name"></a>`name`

Name of the chain eg: LOG_DROPS

##### <a name="-firewalld_direct_chain--provider"></a>`provider`

The specific backend to use for this `firewalld_direct_chain` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="-firewalld_direct_chain--table"></a>`table`

namevar

Name of the table type to add (e.g: filter, nat, mangle, raw)

### <a name="firewalld_direct_passthrough"></a>`firewalld_direct_passthrough`

Allow to create a custom passthroughhrough traffic in iptables/ip6tables/ebtables using firewalld direct interface.

Example:

    firewalld_direct_passthrough {'Forward traffic from OUTPUT to OUTPUT_filter':
        ensure        => 'present',
        inet_protocol => 'ipv4',
        args          => '-A OUTPUT -j OUTPUT_filter',
    }

Or using namevar

    firewalld_direct_passthrough {'-A OUTPUT -j OUTPUT_filter':
        ensure        => 'present',
    }

#### Properties

The following properties are available in the `firewalld_direct_passthrough` type.

##### `ensure`

Valid values: `present`, `absent`

Manage the state of this type.

Default value: `present`

#### Parameters

The following parameters are available in the `firewalld_direct_passthrough` type.

* [`args`](#-firewalld_direct_passthrough--args)
* [`inet_protocol`](#-firewalld_direct_passthrough--inet_protocol)
* [`provider`](#-firewalld_direct_passthrough--provider)

##### <a name="-firewalld_direct_passthrough--args"></a>`args`

namevar

Name of the passthroughhrough to add (e.g: -A OUTPUT -j OUTPUT_filter)

##### <a name="-firewalld_direct_passthrough--inet_protocol"></a>`inet_protocol`

Valid values: `ipv4`, `ipv6`, `eb`

Name of the TCP/IP protocol to use (e.g: ipv4, ipv6, eb)

Default value: `ipv4`

##### <a name="-firewalld_direct_passthrough--provider"></a>`provider`

The specific backend to use for this `firewalld_direct_passthrough` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

### <a name="firewalld_direct_purge"></a>`firewalld_direct_purge`

Allow to purge direct rules in iptables/ip6tables/ebtables using firewalld direct interface.

Example:

    firewalld_direct_purge {'chain': }
    firewalld_direct_purge {'passthrough': }
    firewalld_direct_purge {'rule': }

#### Properties

The following properties are available in the `firewalld_direct_purge` type.

##### `ensure`

Valid values: `purgable`, `purged`

Manage the state of this type.

Default value: `purged`

#### Parameters

The following parameters are available in the `firewalld_direct_purge` type.

* [`name`](#-firewalld_direct_purge--name)
* [`provider`](#-firewalld_direct_purge--provider)
* [`purge`](#-firewalld_direct_purge--purge)

##### <a name="-firewalld_direct_purge--name"></a>`name`

Valid values: `chain`, `passthrough`, `rule`

namevar

Type of resource to purge, valid values are 'chain', 'passthrough' and 'rule'

##### <a name="-firewalld_direct_purge--provider"></a>`provider`

The specific backend to use for this `firewalld_direct_purge` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="-firewalld_direct_purge--purge"></a>`purge`

Valid values: `true`, `false`

If unmaintained definitions should be purged

Default value: `true`

### <a name="firewalld_direct_rule"></a>`firewalld_direct_rule`

Allow to pass rules directly to iptables/ip6tables/ebtables using firewalld direct interface.

Example:

    firewalld_direct_rule {'Allow outgoing SSH connection':
        ensure         => 'present',
        inet_protocol  => 'ipv4',
        table          => 'filter',
        chain          => 'OUTPUT',
        priority       => 1,
        args           => '-p tcp --dport=22 -j ACCEPT',
    }

#### Properties

The following properties are available in the `firewalld_direct_rule` type.

##### `ensure`

Valid values: `present`, `absent`

Manage the state of this type.

Default value: `present`

#### Parameters

The following parameters are available in the `firewalld_direct_rule` type.

* [`args`](#-firewalld_direct_rule--args)
* [`chain`](#-firewalld_direct_rule--chain)
* [`inet_protocol`](#-firewalld_direct_rule--inet_protocol)
* [`name`](#-firewalld_direct_rule--name)
* [`priority`](#-firewalld_direct_rule--priority)
* [`provider`](#-firewalld_direct_rule--provider)
* [`table`](#-firewalld_direct_rule--table)

##### <a name="-firewalld_direct_rule--args"></a>`args`

<args> can be all iptables, ip6tables and ebtables command line arguments

##### <a name="-firewalld_direct_rule--chain"></a>`chain`

Name of the chain type to add (e.g: INPUT, OUTPUT, FORWARD)

##### <a name="-firewalld_direct_rule--inet_protocol"></a>`inet_protocol`

Valid values: `ipv4`, `ipv6`, `eb`

Name of the TCP/IP protocol to use (e.g: ipv4, ipv6, eb)

Default value: `ipv4`

##### <a name="-firewalld_direct_rule--name"></a>`name`

namevar

Name of the rule resource in Puppet

##### <a name="-firewalld_direct_rule--priority"></a>`priority`

The priority number of the rule (e.g: 0, 1, 2, ... 99)

##### <a name="-firewalld_direct_rule--provider"></a>`provider`

The specific backend to use for this `firewalld_direct_rule` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="-firewalld_direct_rule--table"></a>`table`

Name of the table type to add (e.g: filter, nat, mangle, raw)

### <a name="firewalld_ipset"></a>`firewalld_ipset`

Configure IPsets in Firewalld

Example:
    firewalld_ipset {'internal net':
        ensure   => 'present',
        type     => 'hash:net',
        family   => 'inet',
        entries  => ['192.168.0.0/24']
    }

#### Properties

The following properties are available in the `firewalld_ipset` type.

##### `ensure`

Valid values: `present`, `absent`

Manage the state of this type.

Default value: `present`

##### `entries`

Array of ipset entries

##### `family`

Valid values: `inet6`, `inet`

Protocol family of the IPSet

##### `hashsize`

Initial hash size of the IPSet

##### `maxelem`

Valid values: `%r{^[1-9]\d*$}`

Maximal number of elements that can be stored in the set

##### `timeout`

Valid values: `%r{^\d+$}`

Timeout in seconds before entries expiry. 0 means entry is permanent

#### Parameters

The following parameters are available in the `firewalld_ipset` type.

* [`manage_entries`](#-firewalld_ipset--manage_entries)
* [`name`](#-firewalld_ipset--name)
* [`options`](#-firewalld_ipset--options)
* [`provider`](#-firewalld_ipset--provider)
* [`type`](#-firewalld_ipset--type)

##### <a name="-firewalld_ipset--manage_entries"></a>`manage_entries`

Valid values: `true`, `false`, `yes`, `no`

Should we manage entries in this ipset or leave another process manage those entries

Default value: `true`

##### <a name="-firewalld_ipset--name"></a>`name`

namevar

Name of the IPset

##### <a name="-firewalld_ipset--options"></a>`options`

Hash of options for the IPset, eg { 'family' => 'inet6' }

##### <a name="-firewalld_ipset--provider"></a>`provider`

The specific backend to use for this `firewalld_ipset` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-firewalld_ipset--type"></a>`type`

Valid values: `bitmap:ip`, `bitmap:ip,mac`, `bitmap:port`, `hash:ip`, `hash:ip,mark`, `hash:ip,port`, `hash:ip,port,ip`, `hash:ip,port,net`, `hash:mac`, `hash:net`, `hash:net,iface`, `hash:net,net`, `hash:net,port`, `hash:net,port,net`, `list:set`

Type of the ipset (default: hash:ip)

Default value: `hash:ip`

### <a name="firewalld_policy"></a>`firewalld_policy`

Creates and manages firewalld policies.

Note that setting `ensure => 'absent'` to the built in firewalld
policies will not work, and will generate an error. This is a
limitation of firewalld itself, not the module.

#### Examples

##### Create a policy called `anytorestricted`

```puppet
firewalld_policy { 'anytorestricted':
  ensure           => present,
  target           => '%%REJECT%%',
  ingress_zones    => ['ANY'],
  egress_zones     => ['restricted'],
  purge_rich_rules => true,
  purge_services   => true,
  purge_ports      => true,
  icmp_blocks      => 'router-advertisement'
}
```

#### Properties

The following properties are available in the `firewalld_policy` type.

##### `egress_zones`

Specify the egress zones for the policy as an array of strings

##### `ensure`

Valid values: `present`, `absent`

Manage the state of this type.

Default value: `present`

##### `icmp_blocks`

Specify the icmp-blocks for the policy. Can be a single string specifying one icmp type,
or an array of strings specifying multiple icmp types. Any blocks not specified here will be removed

##### `ingress_zones`

Specify the ingress zones for the policy as an array of strings

##### `masquerade`

Valid values: `true`, `false`

Can be set to true or false, specifies whether to add or remove masquerading from the policy

##### `priority`

The priority of the policy as an integer (default -1)

Default value: `-1`

##### `purge_ports`

Valid values: `false`, `true`

When set to true any ports associated with this policy
that are not managed by Puppet will be removed.

##### `purge_rich_rules`

Valid values: `false`, `true`

When set to true any rich_rules associated with this policy
that are not managed by Puppet will be removed.

##### `purge_services`

Valid values: `false`, `true`

When set to true any services associated with this policy
that are not managed by Puppet will be removed.

##### `target`

Specify the target for the policy

#### Parameters

The following parameters are available in the `firewalld_policy` type.

* [`description`](#-firewalld_policy--description)
* [`name`](#-firewalld_policy--name)
* [`policy`](#-firewalld_policy--policy)
* [`provider`](#-firewalld_policy--provider)
* [`short`](#-firewalld_policy--short)

##### <a name="-firewalld_policy--description"></a>`description`

Description of the policy to add

##### <a name="-firewalld_policy--name"></a>`name`

namevar

Name of the rule resource in Puppet

##### <a name="-firewalld_policy--policy"></a>`policy`

Name of the policy

##### <a name="-firewalld_policy--provider"></a>`provider`

The specific backend to use for this `firewalld_policy` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-firewalld_policy--short"></a>`short`

Short description of the policy to add

### <a name="firewalld_port"></a>`firewalld_port`

Assigns a port to a specific firewalld zone.

firewalld_port will autorequire the firewalld_zone specified in
the zone parameter or the firewalld_policy specified in the policy
parameter so there is no need to add dependencies for this

Example:

    firewalld_port {'Open port 8080 in the public Zone':
        ensure   => 'present',
        zone     => 'public',
        port     => 8080,
        protocol => 'tcp',
    }

#### Properties

The following properties are available in the `firewalld_port` type.

##### `ensure`

Valid values: `present`, `absent`

Manage the state of this type.

Default value: `present`

#### Parameters

The following parameters are available in the `firewalld_port` type.

* [`name`](#-firewalld_port--name)
* [`policy`](#-firewalld_port--policy)
* [`port`](#-firewalld_port--port)
* [`protocol`](#-firewalld_port--protocol)
* [`provider`](#-firewalld_port--provider)
* [`zone`](#-firewalld_port--zone)

##### <a name="-firewalld_port--name"></a>`name`

namevar

Name of the port resource in Puppet

##### <a name="-firewalld_port--policy"></a>`policy`

Name of the policy to which you want to add the port, exactly one of zone and policy must be supplied

Default value: `unset`

##### <a name="-firewalld_port--port"></a>`port`

Specify the element as a port

##### <a name="-firewalld_port--protocol"></a>`protocol`

Specify the element as a protocol

##### <a name="-firewalld_port--provider"></a>`provider`

The specific backend to use for this `firewalld_port` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-firewalld_port--zone"></a>`zone`

Name of the zone to which you want to add the port, exactly one of zone and policy must be supplied

Default value: `unset`

### <a name="firewalld_rich_rule"></a>`firewalld_rich_rule`

Manages firewalld rich rules.

firewalld_rich_rules will autorequire the firewalld_zone specified
in the zone parameter or the firewalld_policy specified in the
policy parameter so there is no need to add dependencies for this

Example:

  firewalld_rich_rule { 'Accept SSH from barny':
    ensure => present,
    zone   => 'restricted',
    source => '192.168.1.2/32',
    service => 'ssh',
    action  => 'accept',
  }

#### Properties

The following properties are available in the `firewalld_rich_rule` type.

##### `ensure`

Valid values: `present`, `absent`

Manage the state of this type.

Default value: `present`

#### Parameters

The following parameters are available in the `firewalld_rich_rule` type.

* [`action`](#-firewalld_rich_rule--action)
* [`audit`](#-firewalld_rich_rule--audit)
* [`dest`](#-firewalld_rich_rule--dest)
* [`family`](#-firewalld_rich_rule--family)
* [`forward_port`](#-firewalld_rich_rule--forward_port)
* [`icmp_block`](#-firewalld_rich_rule--icmp_block)
* [`icmp_type`](#-firewalld_rich_rule--icmp_type)
* [`log`](#-firewalld_rich_rule--log)
* [`masquerade`](#-firewalld_rich_rule--masquerade)
* [`name`](#-firewalld_rich_rule--name)
* [`policy`](#-firewalld_rich_rule--policy)
* [`port`](#-firewalld_rich_rule--port)
* [`priority`](#-firewalld_rich_rule--priority)
* [`protocol`](#-firewalld_rich_rule--protocol)
* [`provider`](#-firewalld_rich_rule--provider)
* [`raw_rule`](#-firewalld_rich_rule--raw_rule)
* [`service`](#-firewalld_rich_rule--service)
* [`source`](#-firewalld_rich_rule--source)
* [`zone`](#-firewalld_rich_rule--zone)

##### <a name="-firewalld_rich_rule--action"></a>`action`

Specify the action fo this rule

##### <a name="-firewalld_rich_rule--audit"></a>`audit`

doc

##### <a name="-firewalld_rich_rule--dest"></a>`dest`

Specify destination address, this can be a string of the IP address or a hash containing other options

##### <a name="-firewalld_rich_rule--family"></a>`family`

Valid values: `ipv4`, `ipv6`, `eb`

IP family, one of ipv4, ipv6 or eb, defauts to ipv4

Default value: `ipv4`

##### <a name="-firewalld_rich_rule--forward_port"></a>`forward_port`

Specify the element as forward-port

##### <a name="-firewalld_rich_rule--icmp_block"></a>`icmp_block`

Specify the element as an icmp-block

##### <a name="-firewalld_rich_rule--icmp_type"></a>`icmp_type`

Specify the element as an icmp-type

##### <a name="-firewalld_rich_rule--log"></a>`log`

doc

##### <a name="-firewalld_rich_rule--masquerade"></a>`masquerade`

Specify the element as masquerade

##### <a name="-firewalld_rich_rule--name"></a>`name`

namevar

Name of the rule resource in Puppet

##### <a name="-firewalld_rich_rule--policy"></a>`policy`

Name of the policy to attach the rich rule to, exactly one of zone and policy must be supplied

Default value: `unset`

##### <a name="-firewalld_rich_rule--port"></a>`port`

Specify the element as a port

##### <a name="-firewalld_rich_rule--priority"></a>`priority`

Rule priority, it can be in the range of -32768 to 32767

##### <a name="-firewalld_rich_rule--protocol"></a>`protocol`

Specify the element as a protocol

##### <a name="-firewalld_rich_rule--provider"></a>`provider`

The specific backend to use for this `firewalld_rich_rule` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="-firewalld_rich_rule--raw_rule"></a>`raw_rule`

Manage the entire rule as one string - this is used
internally by firwalld_zone and firewalld_policy to handle
pruning of rules

##### <a name="-firewalld_rich_rule--service"></a>`service`

Specify the element as a service

##### <a name="-firewalld_rich_rule--source"></a>`source`

Specify source address, this can be a string of the IP address or a hash containing other options

##### <a name="-firewalld_rich_rule--zone"></a>`zone`

Name of the zone to attach the rich rule to, exactly one of zone and policy must be supplied

Default value: `unset`

### <a name="firewalld_service"></a>`firewalld_service`

Assigns a service to a specific firewalld zone.

`firewalld_service` will autorequire the `firewalld_zone` specified
in the `zone` parameter or the `firewalld_policy` specified in the
`policy` parameter and the `firewalld::custom_service` specified in
the `service` parameter. There is no need to manually add
dependencies for this.

#### Examples

##### Allowing SSH

```puppet
firewalld_service {'Allow SSH in the public Zone':
    ensure  => present,
    zone    => 'public',
    service => 'ssh',
}
```

#### Properties

The following properties are available in the `firewalld_service` type.

##### `ensure`

Valid values: `present`, `absent`

Manage the state of this type.

Default value: `present`

#### Parameters

The following parameters are available in the `firewalld_service` type.

* [`name`](#-firewalld_service--name)
* [`policy`](#-firewalld_service--policy)
* [`provider`](#-firewalld_service--provider)
* [`service`](#-firewalld_service--service)
* [`zone`](#-firewalld_service--zone)

##### <a name="-firewalld_service--name"></a>`name`

namevar

Name of the service resource in Puppet

##### <a name="-firewalld_service--policy"></a>`policy`

Name of the policy to which you want to add the service, exactly one of zone and policy must be supplied

Default value: `unset`

##### <a name="-firewalld_service--provider"></a>`provider`

The specific backend to use for this `firewalld_service` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-firewalld_service--service"></a>`service`

Name of the service to add

##### <a name="-firewalld_service--zone"></a>`zone`

Name of the zone to which you want to add the service, exactly one of zone and policy must be supplied

Default value: `unset`

### <a name="firewalld_zone"></a>`firewalld_zone`

Creates and manages firewalld zones.

Note that setting `ensure => 'absent'` to the built in firewalld zones will
not work, and will generate an error. This is a limitation of firewalld itself, not the module.

#### Examples

##### Create a zone called `restricted` allowing only `echo-request` icmp types

```puppet
firewalld_zone { 'restricted':
  ensure               => present,
  target               => '%%REJECT%%',
  interfaces           => [],
  sources              => [],
  purge_rich_rules     => true,
  purge_services       => true,
  purge_ports          => true,
  icmp_blocks          => 'echo-request'
  icmp_block_inversion => true,
}
```

#### Properties

The following properties are available in the `firewalld_zone` type.

##### `ensure`

Valid values: `present`, `absent`

Manage the state of this type.

Default value: `present`

##### `icmp_block_inversion`

Valid values: `true`, `false`

Can be set to true or false, specifies whether to set icmp_block_inversion from the zone

Default value: `false`

##### `icmp_blocks`

Specify the icmp-blocks for the zone. Can be a single string specifying one icmp type,
or an array of strings specifying multiple icmp types. Any blocks not specified here will be removed

##### `interfaces`

Specify the interfaces for the zone

##### `masquerade`

Valid values: `true`, `false`

Can be set to true or false, specifies whether to add or remove masquerading from the zone

##### `protocols`

Specify the protocols for the zone

##### `purge_ports`

Valid values: `false`, `true`

When set to true any ports associated with this zone
that are not managed by Puppet will be removed.

##### `purge_rich_rules`

Valid values: `false`, `true`

When set to true any rich_rules associated with this zone
that are not managed by Puppet will be removed.

##### `purge_services`

Valid values: `false`, `true`

When set to true any services associated with this zone
that are not managed by Puppet will be removed.

##### `sources`

Specify the sources for the zone

##### `target`

Specify the target for the zone

#### Parameters

The following parameters are available in the `firewalld_zone` type.

* [`description`](#-firewalld_zone--description)
* [`name`](#-firewalld_zone--name)
* [`provider`](#-firewalld_zone--provider)
* [`short`](#-firewalld_zone--short)
* [`zone`](#-firewalld_zone--zone)

##### <a name="-firewalld_zone--description"></a>`description`

Description of the zone to add

##### <a name="-firewalld_zone--name"></a>`name`

namevar

Name of the rule resource in Puppet

##### <a name="-firewalld_zone--provider"></a>`provider`

The specific backend to use for this `firewalld_zone` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-firewalld_zone--short"></a>`short`

Short description of the zone to add

##### <a name="-firewalld_zone--zone"></a>`zone`

Name of the zone

## Functions

### <a name="firewalld--safe_filename"></a>`firewalld::safe_filename`

Type: Puppet Language

Returns a string that is safe for firewalld filenames

#### Examples

##### Regular Filename

```puppet
$filename = 'B@d Characters!'
firewalld::safe_filename($orig_string)

Result => 'B_d_Characters_'
```

##### Filename with Options

```puppet
$filename = 'B@d Characters!.txt'
firewalld::safe_filename(
  $filename,
  {
    'replacement_string' => '--',
    'file_extension'     => '.txt'
  }
)

Result => 'B--d--Characters--.txt'
```

#### `firewalld::safe_filename(String[1] $filename, Struct[
    {
      'replacement_string' => Pattern[/^[\w-]+$/],
      'file_extension'     => Optional[String[1]]
    }
  ] $options = { 'replacement_string' => '_' })`

The firewalld::safe_filename function.

Returns: `String` Processed string

##### Examples

###### Regular Filename

```puppet
$filename = 'B@d Characters!'
firewalld::safe_filename($orig_string)

Result => 'B_d_Characters_'
```

###### Filename with Options

```puppet
$filename = 'B@d Characters!.txt'
firewalld::safe_filename(
  $filename,
  {
    'replacement_string' => '--',
    'file_extension'     => '.txt'
  }
)

Result => 'B--d--Characters--.txt'
```

##### `filename`

Data type: `String[1]`

The String to process

##### `options`

Data type:

```puppet
Struct[
    {
      'replacement_string' => Pattern[/^[\w-]+$/],
      'file_extension'     => Optional[String[1]]
    }
  ]
```

Various processing options

Options:

* **file_extension** `String[1]`: This will be stripped from the end of the string prior to processing and
re-added afterwards

##### `options`

Data type: `String[1]`

replacement_string
The String to use when replacing invalid characters

Options:

* **file_extension** `String[1]`: This will be stripped from the end of the string prior to processing and
re-added afterwards

